@@ -1,6 +1,11 @@
-from unittest import TestCase
+from rq.compat import is_python_version
+if is_python_version((2, 7), (3, 2)):
+    from unittest import TestCase
+else:
+    from unittest2 import TestCase  # noqa
 from rq.scripts import read_config_file
 
+
 class TestScripts(TestCase):
     def test_config_file(self):
         settings = read_config_file("tests.dummy_settings")
